@@ -2,9 +2,10 @@ TIMESTAMP = 'timestamp'
 ICAO = 'icao'
 
 LAST_UPDATE = 'last_update'
+MSG_TYPE = 'msg_type'
 
 SESSION = 'session'
-SESSION_UUID = 'session_uuid'
+SESSION_HASH = 'session_hash'
 HOST = 'host'
 PORT = 'port'
 START = 'start'
